stalker.core.models.Sequence — Stalker v0.1.1.a9 documentation

### Navigation

- index
- next |
- previous |
- Stalker v0.1.1.a9 documentation »

# stalker.core.models.Sequence

class `stalker.core.models.` `Sequence`(shots=[], lead=None, **kwargs)

  Bases: `stalker.core.models.Entity`, `stalker.core.mixins.ReferenceMixin`, `stalker.core.mixins.StatusMixin`, `stalker.core.mixins.ScheduleMixin`, `stalker.core.mixins.TaskMixin`, `stalker.core.mixins.ProjectMixin`

  Stores data about Sequences.

  Sequences are holders of the `Shot` objects. They orginize the conceptual data with another level of complexity.

  Parameters: | lead (`User`) – The lead of this Seuqence. The default value is None.

  `__init__`(shots=[], lead=None, **kwargs)

  Methods

  `__init__`(**kwargs[, shots, lead]) |

  Attributes

  `code` | The code name of this object.
  `created_by` | The `User` who has created this object.
  `date_created` | A `datetime.datetime` instance showing the creation date and time of this object.
  `date_updated` | A `datetime.datetime` instance showing the update date and time of this object.
  `description` | Description of this object.
  `due_date` | The date that the entity should be delivered.
  `duration` | Duration of the entity.
  `lead` | The lead of this sequence object.
  `name` | Name of this object
  `nice_name` | Nice name of this object.
  `notes` | All the notes about this entity.
  `project` | A `Project` instance showing the
  `references` | References are lists containing `Entity` instances.
  `shots` | The shots of this sequence object.
  `start_date` | The date that this entity should start.
  `status` | The current status index of the object.
  `status_list` | The list of statuses that this object can have.
  `tags` | A list of tags attached to this object.
  `tasks` | The list of `Task` instances.
  `type` | The type of the object.
  `updated_by` | The `User` who has updated this object.

  `lead`

    The lead of this sequence object.

  `shots`

    The shots of this sequence object.

  `code`

    The code name of this object.

    It accepts string or unicode values and any other kind of objects will be converted to string. In any update to the name attribute the code also will be updated. If the code is not initialized or given as None, it will be set to the uppercase version of the nice_name attribute. Setting the code attribute to None will reset it to the default value. The default value is the upper case form of the nice_name.

  `created_by`

    The `User` who has created this object.

  `date_created`

    A `datetime.datetime` instance showing the creation date and time of this object.

  `date_updated`

    A `datetime.datetime` instance showing the update date and time of this object.

  `description`

    Description of this object.

  `due_date`

    The date that the entity should be delivered.

    The due_date can be set to a datetime.timedelta and in this case it will be calculated as an offset from the start_date and converted to datetime.date again. Setting the start_date to a date passing the due_date will also set the due_date so the timedelta between them is preserved, default value is 10 days

  `duration`

    Duration of the entity.

    It is a datetime.timedelta instance. Showing the difference of the `start_date` and the `due_date`. If edited it changes the `due_date` attribute value.

  `name`

    Name of this object

  `nice_name`

    Nice name of this object.

    It has the same value with the name (contextually) but with a different format like, all the white spaces replaced by underscores (“_”), all the CamelCase form will be expanded by underscore (_) characters and it is always lower case.

    There is also the `code` attribute which is simply the upper case form of `nice_name` if it is not defined differently (i.e set to another value).

  `notes`

    All the notes about this entity.

    It is a list of `Note` objects or an empty list, None will be converted to an empty list.

  `project`

    A `Project` instance showing the relation of this object to a Stalker `Project`

  `references`

    References are lists containing `Entity` instances.

  `start_date`

    The date that this entity should start.

    Also effects the `due_date` attribute value in certain conditions, if the `start_date` is set to a time passing the `due_date` it will also offset the `due_date` to keep the `duration` value fixed. `start_date` should be an instance of class:datetime.date and the default value is `datetime.date.today()`

  `status`

    The current status index of the object.

    This is an integer value and shows the index of the `Status` object in the `StatusList` of this object.

  `status_list`

    The list of statuses that this object can have.

  `tags`

    A list of tags attached to this object.

    It is a list of `Tag` instances which shows the tags of this object

  `tasks`

    The list of `Task` instances.

  `type`

    The type of the object.

    It is an instance of `Type` with a proper `target_entity_type`.

  `updated_by`

    The `User` who has updated this object.

### Navigation

- index
- next |
- previous |
- Stalker v0.1.1.a9 documentation »